import aoi_pb2 as _aoi_pb2
import common_models_pb2 as _common_models_pb2
import common_models_pb2 as _common_models_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from aoi_pb2 import AOITransaction as AOITransaction
from aoi_pb2 import AOIIdentifier as AOIIdentifier
from aoi_pb2 import AOIObject as AOIObject
from aoi_pb2 import AOIVersion as AOIVersion
from aoi_pb2 import AOIInput as AOIInput
from aoi_pb2 import AOICreateRequest as AOICreateRequest
from aoi_pb2 import AOICreateResponse as AOICreateResponse
from aoi_pb2 import AOIUploadRequest as AOIUploadRequest
from aoi_pb2 import AOIUploadResponse as AOIUploadResponse
from aoi_pb2 import AOIGetRequest as AOIGetRequest
from aoi_pb2 import AOIGetResponse as AOIGetResponse
from aoi_pb2 import AOIUpdateRequest as AOIUpdateRequest
from aoi_pb2 import AOIUpdateResponse as AOIUpdateResponse
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class AOITransactionStatusRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class AOITransactionStatusResponse(_message.Message):
    __slots__ = ("status_code", "transaction")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    transaction: _aoi_pb2.AOITransaction
    def __init__(self, status_code: _Optional[int] = ..., transaction: _Optional[_Union[_aoi_pb2.AOITransaction, _Mapping]] = ...) -> None: ...

class AOITransactionGetRequest(_message.Message):
    __slots__ = ("pagination", "id")
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    pagination: _common_models_pb2_1.Pagination
    id: str
    def __init__(self, pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., id: _Optional[str] = ...) -> None: ...

class AOITransactionGetResponse(_message.Message):
    __slots__ = ("status_code", "pagination", "aoi_identifiers")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    AOI_IDENTIFIERS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    pagination: _common_models_pb2_1.Pagination
    aoi_identifiers: _containers.RepeatedCompositeFieldContainer[_aoi_pb2.AOIIdentifier]
    def __init__(self, status_code: _Optional[int] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., aoi_identifiers: _Optional[_Iterable[_Union[_aoi_pb2.AOIIdentifier, _Mapping]]] = ...) -> None: ...



import common_models_pb2 as _common_models_pb2
import user_pb2 as _user_pb2
import common_models_pb2 as _common_models_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from user_pb2 import LoginRequest as LoginRequest
from user_pb2 import LoginResponse as LoginResponse
from user_pb2 import UserChangePasswordRequest as UserChangePasswordRequest
from user_pb2 import UserChangePasswordResponse as UserChangePasswordResponse
from user_pb2 import UserGenerateTempPasswordRequest as UserGenerateTempPasswordRequest
from user_pb2 import UserGenerateTempPasswordResponse as UserGenerateTempPasswordResponse
from user_pb2 import User as User
from user_pb2 import UserCreateRequest as UserCreateRequest
from user_pb2 import UserCreateResponse as UserCreateResponse
from user_pb2 import UserUpdateRequest as UserUpdateRequest
from user_pb2 import UserUpdateResponse as UserUpdateResponse
from user_pb2 import UserDeleteRequest as UserDeleteRequest
from user_pb2 import UserDeleteResponse as UserDeleteResponse
from user_pb2 import UserGetRequest as UserGetRequest
from user_pb2 import UserGetResponse as UserGetResponse
from user_pb2 import UserListRequest as UserListRequest
from user_pb2 import UserListResponse as UserListResponse
from user_pb2 import KeyValuePair as KeyValuePair
from user_pb2 import UserPropertiesGetRequest as UserPropertiesGetRequest
from user_pb2 import UserPropertiesGetResponse as UserPropertiesGetResponse
from user_pb2 import UserPropertiesUpdateRequest as UserPropertiesUpdateRequest
from user_pb2 import UserPropertiesUpdateResponse as UserPropertiesUpdateResponse

DESCRIPTOR: _descriptor.FileDescriptor

class UserCollection(_message.Message):
    __slots__ = ("id", "name", "users")
    class WellKnownIds(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        USER_COLLECTION_UNKNOWN: _ClassVar[UserCollection.WellKnownIds]
        USER_COLLECTION_ID_PUBLIC: _ClassVar[UserCollection.WellKnownIds]
    USER_COLLECTION_UNKNOWN: UserCollection.WellKnownIds
    USER_COLLECTION_ID_PUBLIC: UserCollection.WellKnownIds
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    users: _containers.RepeatedCompositeFieldContainer[_user_pb2.User]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., users: _Optional[_Iterable[_Union[_user_pb2.User, _Mapping]]] = ...) -> None: ...

class UserCollectionCreateRequest(_message.Message):
    __slots__ = ("name", "parent_collection_ids")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PARENT_COLLECTION_IDS_FIELD_NUMBER: _ClassVar[int]
    name: str
    parent_collection_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., parent_collection_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class UserCollectionCreateResponse(_message.Message):
    __slots__ = ("status_code", "collection")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    collection: UserCollection
    def __init__(self, status_code: _Optional[int] = ..., collection: _Optional[_Union[UserCollection, _Mapping]] = ...) -> None: ...

class UserCollectionGetRequest(_message.Message):
    __slots__ = ("collection", "include_users")
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_USERS_FIELD_NUMBER: _ClassVar[int]
    collection: UserCollection
    include_users: bool
    def __init__(self, collection: _Optional[_Union[UserCollection, _Mapping]] = ..., include_users: bool = ...) -> None: ...

class UserCollectionGetResponse(_message.Message):
    __slots__ = ("status_code", "collection")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    collection: UserCollection
    def __init__(self, status_code: _Optional[int] = ..., collection: _Optional[_Union[UserCollection, _Mapping]] = ...) -> None: ...

class UserCollectionUpdateRequest(_message.Message):
    __slots__ = ("collection",)
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    collection: UserCollection
    def __init__(self, collection: _Optional[_Union[UserCollection, _Mapping]] = ...) -> None: ...

class UserCollectionUpdateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class UserCollectionDeleteRequest(_message.Message):
    __slots__ = ("collection_id",)
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    def __init__(self, collection_id: _Optional[str] = ...) -> None: ...

class UserCollectionDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class UserCollectionAddUserRequest(_message.Message):
    __slots__ = ("user_id", "collection_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    collection_id: str
    def __init__(self, user_id: _Optional[str] = ..., collection_id: _Optional[str] = ...) -> None: ...

class UserCollectionAddUserResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class UserCollectionRemoveUserRequest(_message.Message):
    __slots__ = ("user_id", "collection_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    collection_id: str
    def __init__(self, user_id: _Optional[str] = ..., collection_id: _Optional[str] = ...) -> None: ...

class UserCollectionRemoveUserResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class UserCollectionListRequest(_message.Message):
    __slots__ = ("parent_collection_id", "collection_type", "search_text", "max_search_depth", "include_users")
    class UserCollectionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_USER_COLLECTION_TYPE: _ClassVar[UserCollectionListRequest.UserCollectionType]
        USER_COLLECTION_TYPE_ANY: _ClassVar[UserCollectionListRequest.UserCollectionType]
        USER_COLLECTION_TYPE_CUSTOMER: _ClassVar[UserCollectionListRequest.UserCollectionType]
        USER_COLLECTION_TYPE_DEPARTMENT: _ClassVar[UserCollectionListRequest.UserCollectionType]
        USER_COLLECTION_TYPE_USER: _ClassVar[UserCollectionListRequest.UserCollectionType]
        USER_COLLECTION_TYPE_ADMINS: _ClassVar[UserCollectionListRequest.UserCollectionType]
    UNKNOWN_USER_COLLECTION_TYPE: UserCollectionListRequest.UserCollectionType
    USER_COLLECTION_TYPE_ANY: UserCollectionListRequest.UserCollectionType
    USER_COLLECTION_TYPE_CUSTOMER: UserCollectionListRequest.UserCollectionType
    USER_COLLECTION_TYPE_DEPARTMENT: UserCollectionListRequest.UserCollectionType
    USER_COLLECTION_TYPE_USER: UserCollectionListRequest.UserCollectionType
    USER_COLLECTION_TYPE_ADMINS: UserCollectionListRequest.UserCollectionType
    PARENT_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    MAX_SEARCH_DEPTH_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_USERS_FIELD_NUMBER: _ClassVar[int]
    parent_collection_id: str
    collection_type: UserCollectionListRequest.UserCollectionType
    search_text: str
    max_search_depth: int
    include_users: bool
    def __init__(self, parent_collection_id: _Optional[str] = ..., collection_type: _Optional[_Union[UserCollectionListRequest.UserCollectionType, str]] = ..., search_text: _Optional[str] = ..., max_search_depth: _Optional[int] = ..., include_users: bool = ...) -> None: ...

class UserCollectionListResponse(_message.Message):
    __slots__ = ("status_code", "collections")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    COLLECTIONS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    collections: _containers.RepeatedCompositeFieldContainer[UserCollection]
    def __init__(self, status_code: _Optional[int] = ..., collections: _Optional[_Iterable[_Union[UserCollection, _Mapping]]] = ...) -> None: ...



import common_models_pb2 as _common_models_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
import aoi_pb2 as _aoi_pb2
import common_models_pb2 as _common_models_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from aoi_pb2 import AOITransaction as AOITransaction
from aoi_pb2 import AOIIdentifier as AOIIdentifier
from aoi_pb2 import AOIObject as AOIObject
from aoi_pb2 import AOIVersion as AOIVersion
from aoi_pb2 import AOIInput as AOIInput
from aoi_pb2 import AOICreateRequest as AOICreateRequest
from aoi_pb2 import AOICreateResponse as AOICreateResponse
from aoi_pb2 import AOIUploadRequest as AOIUploadRequest
from aoi_pb2 import AOIUploadResponse as AOIUploadResponse
from aoi_pb2 import AOIGetRequest as AOIGetRequest
from aoi_pb2 import AOIGetResponse as AOIGetResponse
from aoi_pb2 import AOIUpdateRequest as AOIUpdateRequest
from aoi_pb2 import AOIUpdateResponse as AOIUpdateResponse

DESCRIPTOR: _descriptor.FileDescriptor

class AOIField(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_AOI_FIELD: _ClassVar[AOIField]
    AOI_ID: _ClassVar[AOIField]
    GEOM_WKT: _ClassVar[AOIField]
    LAT: _ClassVar[AOIField]
    LONG: _ClassVar[AOIField]
    NAME: _ClassVar[AOIField]
    AREA_KM2: _ClassVar[AOIField]
    CATEGORY: _ClassVar[AOIField]
    TYPE: _ClassVar[AOIField]
    SOURCE: _ClassVar[AOIField]
    COUNTRY: _ClassVar[AOIField]
    STATE: _ClassVar[AOIField]
    TAGS: _ClassVar[AOIField]
    ATTRIBUTES: _ClassVar[AOIField]
    TIMEZONE: _ClassVar[AOIField]
    CREATED_ON: _ClassVar[AOIField]
    CREATED_BY: _ClassVar[AOIField]
UNKNOWN_AOI_FIELD: AOIField
AOI_ID: AOIField
GEOM_WKT: AOIField
LAT: AOIField
LONG: AOIField
NAME: AOIField
AREA_KM2: AOIField
CATEGORY: AOIField
TYPE: AOIField
SOURCE: AOIField
COUNTRY: AOIField
STATE: AOIField
TAGS: AOIField
ATTRIBUTES: AOIField
TIMEZONE: AOIField
CREATED_ON: AOIField
CREATED_BY: AOIField

class AOIVersionGetRequest(_message.Message):
    __slots__ = ("ids", "aoi_fields", "pagination")
    IDS_FIELD_NUMBER: _ClassVar[int]
    AOI_FIELDS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[int]
    aoi_fields: _containers.RepeatedScalarFieldContainer[AOIField]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, ids: _Optional[_Iterable[int]] = ..., aoi_fields: _Optional[_Iterable[_Union[AOIField, str]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class AOIVersionGetResponse(_message.Message):
    __slots__ = ("status_code", "pagination", "aoi_versions")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    AOI_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    pagination: _common_models_pb2_1.Pagination
    aoi_versions: _containers.RepeatedCompositeFieldContainer[_aoi_pb2.AOIVersion]
    def __init__(self, status_code: _Optional[int] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., aoi_versions: _Optional[_Iterable[_Union[_aoi_pb2.AOIVersion, _Mapping]]] = ...) -> None: ...

class AOIVersionCreateRequest(_message.Message):
    __slots__ = ("aoi_id", "aoi_modification_input")
    AOI_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_MODIFICATION_INPUT_FIELD_NUMBER: _ClassVar[int]
    aoi_id: str
    aoi_modification_input: _aoi_pb2.AOIInput
    def __init__(self, aoi_id: _Optional[str] = ..., aoi_modification_input: _Optional[_Union[_aoi_pb2.AOIInput, _Mapping]] = ...) -> None: ...

class AOIVersionCreateResponse(_message.Message):
    __slots__ = ("status_code", "pagination", "aoi_version")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    AOI_VERSION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    pagination: _common_models_pb2_1.Pagination
    aoi_version: _aoi_pb2.AOIVersion
    def __init__(self, status_code: _Optional[int] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., aoi_version: _Optional[_Union[_aoi_pb2.AOIVersion, _Mapping]] = ...) -> None: ...

class AOIVersionListRequest(_message.Message):
    __slots__ = ("geom_wkt", "category", "tags", "search_text", "min_created_on", "max_created_on", "aoi_fields", "pagination", "verbose", "bbox", "sort_keys", "sort_order", "aoi_type", "country", "state", "min_area", "max_area", "data_sources", "library_type")
    class LibraryType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_LIBRARY_TYPE: _ClassVar[AOIVersionListRequest.LibraryType]
        PRIVATE: _ClassVar[AOIVersionListRequest.LibraryType]
        PUBLIC: _ClassVar[AOIVersionListRequest.LibraryType]
    UNKNOWN_LIBRARY_TYPE: AOIVersionListRequest.LibraryType
    PRIVATE: AOIVersionListRequest.LibraryType
    PUBLIC: AOIVersionListRequest.LibraryType
    class SortOrder(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_SORT_ORDER: _ClassVar[AOIVersionListRequest.SortOrder]
        ASC: _ClassVar[AOIVersionListRequest.SortOrder]
        DESC: _ClassVar[AOIVersionListRequest.SortOrder]
    UNKNOWN_SORT_ORDER: AOIVersionListRequest.SortOrder
    ASC: AOIVersionListRequest.SortOrder
    DESC: AOIVersionListRequest.SortOrder
    GEOM_WKT_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    MIN_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    MAX_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    AOI_FIELDS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    VERBOSE_FIELD_NUMBER: _ClassVar[int]
    BBOX_FIELD_NUMBER: _ClassVar[int]
    SORT_KEYS_FIELD_NUMBER: _ClassVar[int]
    SORT_ORDER_FIELD_NUMBER: _ClassVar[int]
    AOI_TYPE_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    MIN_AREA_FIELD_NUMBER: _ClassVar[int]
    MAX_AREA_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCES_FIELD_NUMBER: _ClassVar[int]
    LIBRARY_TYPE_FIELD_NUMBER: _ClassVar[int]
    geom_wkt: str
    category: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    search_text: str
    min_created_on: _timestamp_pb2.Timestamp
    max_created_on: _timestamp_pb2.Timestamp
    aoi_fields: _containers.RepeatedScalarFieldContainer[AOIField]
    pagination: _common_models_pb2_1.Pagination
    verbose: bool
    bbox: _containers.RepeatedScalarFieldContainer[float]
    sort_keys: AOIField
    sort_order: AOIVersionListRequest.SortOrder
    aoi_type: str
    country: str
    state: str
    min_area: float
    max_area: float
    data_sources: _containers.RepeatedScalarFieldContainer[str]
    library_type: AOIVersionListRequest.LibraryType
    def __init__(self, geom_wkt: _Optional[str] = ..., category: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ..., search_text: _Optional[str] = ..., min_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., aoi_fields: _Optional[_Iterable[_Union[AOIField, str]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., verbose: bool = ..., bbox: _Optional[_Iterable[float]] = ..., sort_keys: _Optional[_Union[AOIField, str]] = ..., sort_order: _Optional[_Union[AOIVersionListRequest.SortOrder, str]] = ..., aoi_type: _Optional[str] = ..., country: _Optional[str] = ..., state: _Optional[str] = ..., min_area: _Optional[float] = ..., max_area: _Optional[float] = ..., data_sources: _Optional[_Iterable[str]] = ..., library_type: _Optional[_Union[AOIVersionListRequest.LibraryType, str]] = ...) -> None: ...

class AOIVersionListResponse(_message.Message):
    __slots__ = ("status_code", "pagination", "aoi_versions")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    AOI_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    pagination: _common_models_pb2_1.Pagination
    aoi_versions: _containers.RepeatedCompositeFieldContainer[_aoi_pb2.AOIVersion]
    def __init__(self, status_code: _Optional[int] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ..., aoi_versions: _Optional[_Iterable[_Union[_aoi_pb2.AOIVersion, _Mapping]]] = ...) -> None: ...



import common_models_pb2 as _common_models_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class Cadence(_message.Message):
    __slots__ = ("frequency", "value")
    class Frequency(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_FREQUENCY: _ClassVar[Cadence.Frequency]
        MINUTELY: _ClassVar[Cadence.Frequency]
        HOURLY: _ClassVar[Cadence.Frequency]
        DAILY: _ClassVar[Cadence.Frequency]
        WEEKLY: _ClassVar[Cadence.Frequency]
        MONTHLY: _ClassVar[Cadence.Frequency]
        YEARLY: _ClassVar[Cadence.Frequency]
    UNKNOWN_FREQUENCY: Cadence.Frequency
    MINUTELY: Cadence.Frequency
    HOURLY: Cadence.Frequency
    DAILY: Cadence.Frequency
    WEEKLY: Cadence.Frequency
    MONTHLY: Cadence.Frequency
    YEARLY: Cadence.Frequency
    FREQUENCY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    frequency: Cadence.Frequency
    value: int
    def __init__(self, frequency: _Optional[_Union[Cadence.Frequency, str]] = ..., value: _Optional[int] = ...) -> None: ...

class Recurrence(_message.Message):
    __slots__ = ("id", "rule", "duration")
    ID_FIELD_NUMBER: _ClassVar[int]
    RULE_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    id: str
    rule: str
    duration: Cadence
    def __init__(self, id: _Optional[str] = ..., rule: _Optional[str] = ..., duration: _Optional[_Union[Cadence, _Mapping]] = ...) -> None: ...

class TOI(_message.Message):
    __slots__ = ("id", "start_local", "finish_local", "recurrences", "exclude_dates", "description")
    ID_FIELD_NUMBER: _ClassVar[int]
    START_LOCAL_FIELD_NUMBER: _ClassVar[int]
    FINISH_LOCAL_FIELD_NUMBER: _ClassVar[int]
    RECURRENCES_FIELD_NUMBER: _ClassVar[int]
    EXCLUDE_DATES_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    start_local: _timestamp_pb2.Timestamp
    finish_local: _timestamp_pb2.Timestamp
    recurrences: _containers.RepeatedCompositeFieldContainer[Recurrence]
    exclude_dates: _containers.RepeatedCompositeFieldContainer[_timestamp_pb2.Timestamp]
    description: str
    def __init__(self, id: _Optional[str] = ..., start_local: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., finish_local: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., recurrences: _Optional[_Iterable[_Union[Recurrence, _Mapping]]] = ..., exclude_dates: _Optional[_Iterable[_Union[_timestamp_pb2.Timestamp, _Mapping]]] = ..., description: _Optional[str] = ...) -> None: ...

class TOICreateRequest(_message.Message):
    __slots__ = ("start_local", "finish_local", "recurrences", "exclude_dates", "description")
    START_LOCAL_FIELD_NUMBER: _ClassVar[int]
    FINISH_LOCAL_FIELD_NUMBER: _ClassVar[int]
    RECURRENCES_FIELD_NUMBER: _ClassVar[int]
    EXCLUDE_DATES_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    start_local: _timestamp_pb2.Timestamp
    finish_local: _timestamp_pb2.Timestamp
    recurrences: _containers.RepeatedCompositeFieldContainer[Recurrence]
    exclude_dates: _containers.RepeatedCompositeFieldContainer[_timestamp_pb2.Timestamp]
    description: str
    def __init__(self, start_local: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., finish_local: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., recurrences: _Optional[_Iterable[_Union[Recurrence, _Mapping]]] = ..., exclude_dates: _Optional[_Iterable[_Union[_timestamp_pb2.Timestamp, _Mapping]]] = ..., description: _Optional[str] = ...) -> None: ...

class TOICreateResponse(_message.Message):
    __slots__ = ("status_code", "toi")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    TOI_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    toi: TOI
    def __init__(self, status_code: _Optional[int] = ..., toi: _Optional[_Union[TOI, _Mapping]] = ...) -> None: ...

class TOIDeleteRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class TOIDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class TOIGetRequest(_message.Message):
    __slots__ = ("ids", "pagination")
    IDS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    pagination: _common_models_pb2.Pagination
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class TOIGetResponse(_message.Message):
    __slots__ = ("status_code", "toi_objects", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    TOI_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    toi_objects: _containers.RepeatedCompositeFieldContainer[TOI]
    pagination: _common_models_pb2.Pagination
    def __init__(self, status_code: _Optional[int] = ..., toi_objects: _Optional[_Iterable[_Union[TOI, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class TOIListRequest(_message.Message):
    __slots__ = ("search_text", "pagination")
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    search_text: str
    pagination: _common_models_pb2.Pagination
    def __init__(self, search_text: _Optional[str] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class TOIListResponse(_message.Message):
    __slots__ = ("status_code", "toi_objects", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    TOI_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    toi_objects: _containers.RepeatedCompositeFieldContainer[TOI]
    pagination: _common_models_pb2.Pagination
    def __init__(self, status_code: _Optional[int] = ..., toi_objects: _Optional[_Iterable[_Union[TOI, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import data_search_pb2 as data__search__pb2

GRPC_GENERATED_VERSION = '1.66.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in data_search_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class DataSearchApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get_schema = channel.unary_unary(
                '/oi.papi.DataSearchApi/get_schema',
                request_serializer=data__search__pb2.DataSearchSchemaGetRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSearchSchemaGetResponse.FromString,
                _registered_method=True)
        self.search = channel.unary_unary(
                '/oi.papi.DataSearchApi/search',
                request_serializer=data__search__pb2.DataSearchRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSearchResponse.FromString,
                _registered_method=True)
        self.get_display_tiles = channel.unary_unary(
                '/oi.papi.DataSearchApi/get_display_tiles',
                request_serializer=data__search__pb2.DataSearchDisplayTilesBatchGetRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSearchDisplayTilesBatchGetResponse.FromString,
                _registered_method=True)
        self.get_resource_batch = channel.unary_unary(
                '/oi.papi.DataSearchApi/get_resource_batch',
                request_serializer=data__search__pb2.DataSearchResourceBatchGetRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSearchResourceBatchGetResponse.FromString,
                _registered_method=True)
        self.get_estimated_summary = channel.unary_unary(
                '/oi.papi.DataSearchApi/get_estimated_summary',
                request_serializer=data__search__pb2.DataSearchEstimatedSummaryGetRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSearchEstimatedSummaryGetResponse.FromString,
                _registered_method=True)
        self.get_download_link = channel.unary_unary(
                '/oi.papi.DataSearchApi/get_download_link',
                request_serializer=data__search__pb2.DataSourceGetDownloadLinkRequest.SerializeToString,
                response_deserializer=data__search__pb2.DataSourceGetDownloadLinkResponse.FromString,
                _registered_method=True)


class DataSearchApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def get_schema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def search(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_display_tiles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_resource_batch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_estimated_summary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_download_link(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSearchApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get_schema': grpc.unary_unary_rpc_method_handler(
                    servicer.get_schema,
                    request_deserializer=data__search__pb2.DataSearchSchemaGetRequest.FromString,
                    response_serializer=data__search__pb2.DataSearchSchemaGetResponse.SerializeToString,
            ),
            'search': grpc.unary_unary_rpc_method_handler(
                    servicer.search,
                    request_deserializer=data__search__pb2.DataSearchRequest.FromString,
                    response_serializer=data__search__pb2.DataSearchResponse.SerializeToString,
            ),
            'get_display_tiles': grpc.unary_unary_rpc_method_handler(
                    servicer.get_display_tiles,
                    request_deserializer=data__search__pb2.DataSearchDisplayTilesBatchGetRequest.FromString,
                    response_serializer=data__search__pb2.DataSearchDisplayTilesBatchGetResponse.SerializeToString,
            ),
            'get_resource_batch': grpc.unary_unary_rpc_method_handler(
                    servicer.get_resource_batch,
                    request_deserializer=data__search__pb2.DataSearchResourceBatchGetRequest.FromString,
                    response_serializer=data__search__pb2.DataSearchResourceBatchGetResponse.SerializeToString,
            ),
            'get_estimated_summary': grpc.unary_unary_rpc_method_handler(
                    servicer.get_estimated_summary,
                    request_deserializer=data__search__pb2.DataSearchEstimatedSummaryGetRequest.FromString,
                    response_serializer=data__search__pb2.DataSearchEstimatedSummaryGetResponse.SerializeToString,
            ),
            'get_download_link': grpc.unary_unary_rpc_method_handler(
                    servicer.get_download_link,
                    request_deserializer=data__search__pb2.DataSourceGetDownloadLinkRequest.FromString,
                    response_serializer=data__search__pb2.DataSourceGetDownloadLinkResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.DataSearchApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.DataSearchApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DataSearchApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def get_schema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/get_schema',
            data__search__pb2.DataSearchSchemaGetRequest.SerializeToString,
            data__search__pb2.DataSearchSchemaGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def search(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/search',
            data__search__pb2.DataSearchRequest.SerializeToString,
            data__search__pb2.DataSearchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_display_tiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/get_display_tiles',
            data__search__pb2.DataSearchDisplayTilesBatchGetRequest.SerializeToString,
            data__search__pb2.DataSearchDisplayTilesBatchGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_resource_batch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/get_resource_batch',
            data__search__pb2.DataSearchResourceBatchGetRequest.SerializeToString,
            data__search__pb2.DataSearchResourceBatchGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_estimated_summary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/get_estimated_summary',
            data__search__pb2.DataSearchEstimatedSummaryGetRequest.SerializeToString,
            data__search__pb2.DataSearchEstimatedSummaryGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_download_link(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataSearchApi/get_download_link',
            data__search__pb2.DataSourceGetDownloadLinkRequest.SerializeToString,
            data__search__pb2.DataSourceGetDownloadLinkResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: analysis_config.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'analysis_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import analysis_pb2 as analysis__pb2
try:
  common__models__pb2 = analysis__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__pb2.common_models_pb2
from terrascope_api.models import analysis_version_pb2 as analysis__version__pb2
try:
  common__models__pb2 = analysis__version__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__version__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__version__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__version__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__version__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__version__pb2.common_models_pb2
try:
  algorithm__version__pb2 = analysis__version__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = analysis__version__pb2.algorithm_version_pb2
try:
  common__models__pb2 = analysis__version__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__version__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__version__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__version__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__version__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__version__pb2.common_models_pb2
from terrascope_api.models import algorithm_config_pb2 as algorithm__config__pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2
try:
  algorithm__pb2 = algorithm__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = algorithm__config__pb2.algorithm_pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = algorithm__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = algorithm__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2
try:
  algorithm__pb2 = algorithm__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = algorithm__config__pb2.algorithm_pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.analysis_pb2 import *
from terrascope_api.models.analysis_version_pb2 import *
from terrascope_api.models.algorithm_config_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61nalysis_config.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\x0e\x61nalysis.proto\x1a\x16\x61nalysis_version.proto\x1a\x16\x61lgorithm_config.proto\"\x8c\x03\n\x0e\x41nalysisConfig\x12#\n\x08\x61nalysis\x18\x01 \x01(\x0b\x32\x11.oi.papi.Analysis\x12\x32\n\x10\x61nalysis_version\x18\x02 \x01(\x0b\x32\x18.oi.papi.AnalysisVersion\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12.\n\ncreated_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x16\x61lgorithm_config_nodes\x18\x07 \x03(\x0b\x32$.oi.papi.AnalysisAlgorithmConfigNode\x12\x33\n\x11\x61lgorithm_configs\x18\x08 \x03(\x0b\x32\x18.oi.papi.AlgorithmConfig\x12\x15\n\ris_deprecated\x18\t \x01(\x08\x12\x16\n\x0eis_deactivated\x18\n \x01(\x08\x12\x18\n\x10resources_locked\x18\x0b \x01(\x08\"\xa3\x01\n\x1b\x41nalysisConfigCreateRequest\x12\x1b\n\x13\x61nalysis_version_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x44\n\x16\x61lgorithm_config_nodes\x18\x04 \x03(\x0b\x32$.oi.papi.AnalysisAlgorithmConfigNode\"e\n\x1c\x41nalysisConfigCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x30\n\x0f\x61nalysis_config\x18\x02 \x01(\x0b\x32\x17.oi.papi.AnalysisConfig\"\x92\x01\n\x1b\x41nalysisConfigUpdateRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x44\n\x16\x61lgorithm_config_nodes\x18\x04 \x03(\x0b\x32$.oi.papi.AnalysisAlgorithmConfigNode\"3\n\x1c\x41nalysisConfigUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"s\n\x18\x41nalysisConfigGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12!\n\x19include_algorithm_details\x18\x02 \x01(\x08\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x8c\x01\n\x19\x41nalysisConfigGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x31\n\x10\x61nalysis_configs\x18\x02 \x03(\x0b\x32\x17.oi.papi.AnalysisConfig\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\xa4\x02\n\x19\x41nalysisConfigListRequest\x12\x13\n\x0b\x61nalysis_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61nalysis_version_id\x18\x02 \x01(\t\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x32\n\x0emin_created_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13include_deactivated\x18\x06 \x01(\x08\x12\x12\n\nsubject_id\x18\x07 \x01(\t\x12\'\n\npagination\x18\x08 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x8d\x01\n\x1a\x41nalysisConfigListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x31\n\x10\x61nalysis_configs\x18\x02 \x03(\x0b\x32\x17.oi.papi.AnalysisConfig\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\".\n\x1f\x41nalysisConfigDeactivateRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"7\n AnalysisConfigDeactivateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xc3\x03\n\x11\x41nalysisConfigApi\x12U\n\x06\x63reate\x12$.oi.papi.AnalysisConfigCreateRequest\x1a%.oi.papi.AnalysisConfigCreateResponse\x12U\n\x06update\x12$.oi.papi.AnalysisConfigUpdateRequest\x1a%.oi.papi.AnalysisConfigUpdateResponse\x12L\n\x03get\x12!.oi.papi.AnalysisConfigGetRequest\x1a\".oi.papi.AnalysisConfigGetResponse\x12O\n\x04list\x12\".oi.papi.AnalysisConfigListRequest\x1a#.oi.papi.AnalysisConfigListResponse\x12\x61\n\ndeactivate\x12(.oi.papi.AnalysisConfigDeactivateRequest\x1a).oi.papi.AnalysisConfigDeactivateResponseP\x01P\x02P\x03P\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analysis_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANALYSISCONFIG']._serialized_start=153
  _globals['_ANALYSISCONFIG']._serialized_end=549
  _globals['_ANALYSISCONFIGCREATEREQUEST']._serialized_start=552
  _globals['_ANALYSISCONFIGCREATEREQUEST']._serialized_end=715
  _globals['_ANALYSISCONFIGCREATERESPONSE']._serialized_start=717
  _globals['_ANALYSISCONFIGCREATERESPONSE']._serialized_end=818
  _globals['_ANALYSISCONFIGUPDATEREQUEST']._serialized_start=821
  _globals['_ANALYSISCONFIGUPDATEREQUEST']._serialized_end=967
  _globals['_ANALYSISCONFIGUPDATERESPONSE']._serialized_start=969
  _globals['_ANALYSISCONFIGUPDATERESPONSE']._serialized_end=1020
  _globals['_ANALYSISCONFIGGETREQUEST']._serialized_start=1022
  _globals['_ANALYSISCONFIGGETREQUEST']._serialized_end=1137
  _globals['_ANALYSISCONFIGGETRESPONSE']._serialized_start=1140
  _globals['_ANALYSISCONFIGGETRESPONSE']._serialized_end=1280
  _globals['_ANALYSISCONFIGLISTREQUEST']._serialized_start=1283
  _globals['_ANALYSISCONFIGLISTREQUEST']._serialized_end=1575
  _globals['_ANALYSISCONFIGLISTRESPONSE']._serialized_start=1578
  _globals['_ANALYSISCONFIGLISTRESPONSE']._serialized_end=1719
  _globals['_ANALYSISCONFIGDEACTIVATEREQUEST']._serialized_start=1721
  _globals['_ANALYSISCONFIGDEACTIVATEREQUEST']._serialized_end=1767
  _globals['_ANALYSISCONFIGDEACTIVATERESPONSE']._serialized_start=1769
  _globals['_ANALYSISCONFIGDEACTIVATERESPONSE']._serialized_end=1824
  _globals['_ANALYSISCONFIGAPI']._serialized_start=1827
  _globals['_ANALYSISCONFIGAPI']._serialized_end=2278
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
import analysis_pb2 as _analysis_pb2
import common_models_pb2 as _common_models_pb2_1
import analysis_version_pb2 as _analysis_version_pb2
import common_models_pb2 as _common_models_pb2_1_1
import analysis_pb2 as _analysis_pb2_1
import algorithm_version_pb2 as _algorithm_version_pb2
import algorithm_config_pb2 as _algorithm_config_pb2
import common_models_pb2 as _common_models_pb2_1_1_1
import algorithm_pb2 as _algorithm_pb2
import algorithm_version_pb2 as _algorithm_version_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from analysis_pb2 import AnalysisAlgorithmNode as AnalysisAlgorithmNode
from analysis_pb2 import AnalysisCreateRequest as AnalysisCreateRequest
from analysis_pb2 import AnalysisCreateResponse as AnalysisCreateResponse
from analysis_pb2 import AnalysisAlgorithmConfigNode as AnalysisAlgorithmConfigNode
from analysis_pb2 import AnalysisGetRequest as AnalysisGetRequest
from analysis_pb2 import Analysis as Analysis
from analysis_pb2 import AnalysisGetResponse as AnalysisGetResponse
from analysis_pb2 import AnalysisListRequest as AnalysisListRequest
from analysis_pb2 import AnalysisListResponse as AnalysisListResponse
from analysis_version_pb2 import AnalysisManifest as AnalysisManifest
from analysis_version_pb2 import AnalysisVersion as AnalysisVersion
from analysis_version_pb2 import AnalysisVersionCreateRequest as AnalysisVersionCreateRequest
from analysis_version_pb2 import AnalysisVersionCreateResponse as AnalysisVersionCreateResponse
from analysis_version_pb2 import AnalysisVersionGetRequest as AnalysisVersionGetRequest
from analysis_version_pb2 import AnalysisVersionGetResponse as AnalysisVersionGetResponse
from analysis_version_pb2 import AnalysisVersionListRequest as AnalysisVersionListRequest
from analysis_version_pb2 import AnalysisVersionListResponse as AnalysisVersionListResponse
from algorithm_config_pb2 import AlgorithmConfig as AlgorithmConfig
from algorithm_config_pb2 import AlgorithmConfigCreateRequest as AlgorithmConfigCreateRequest
from algorithm_config_pb2 import AlgorithmConfigCreateResponse as AlgorithmConfigCreateResponse
from algorithm_config_pb2 import AlgorithmConfigUpdateRequest as AlgorithmConfigUpdateRequest
from algorithm_config_pb2 import AlgorithmConfigUpdateResponse as AlgorithmConfigUpdateResponse
from algorithm_config_pb2 import AlgorithmConfigGetRequest as AlgorithmConfigGetRequest
from algorithm_config_pb2 import AlgorithmConfigGetResponse as AlgorithmConfigGetResponse
from algorithm_config_pb2 import AlgorithmConfigListRequest as AlgorithmConfigListRequest
from algorithm_config_pb2 import AlgorithmConfigListResponse as AlgorithmConfigListResponse
from algorithm_config_pb2 import AlgorithmConfigDeleteRequest as AlgorithmConfigDeleteRequest
from algorithm_config_pb2 import AlgorithmConfigDeleteResponse as AlgorithmConfigDeleteResponse
from algorithm_config_pb2 import AlgorithmConfigDeprecateRequest as AlgorithmConfigDeprecateRequest
from algorithm_config_pb2 import AlgorithmConfigDeprecateResponse as AlgorithmConfigDeprecateResponse
from algorithm_config_pb2 import AlgorithmConfigDeactivateRequest as AlgorithmConfigDeactivateRequest
from algorithm_config_pb2 import AlgorithmConfigDeactivateResponse as AlgorithmConfigDeactivateResponse

DESCRIPTOR: _descriptor.FileDescriptor

class AnalysisConfig(_message.Message):
    __slots__ = ("analysis", "analysis_version", "id", "name", "description", "created_on", "algorithm_config_nodes", "algorithm_configs", "is_deprecated", "is_deactivated", "resources_locked")
    ANALYSIS_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_VERSION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIG_NODES_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    IS_DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    IS_DEACTIVATED_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_LOCKED_FIELD_NUMBER: _ClassVar[int]
    analysis: _analysis_pb2_1.Analysis
    analysis_version: _analysis_version_pb2.AnalysisVersion
    id: str
    name: str
    description: str
    created_on: _timestamp_pb2.Timestamp
    algorithm_config_nodes: _containers.RepeatedCompositeFieldContainer[_analysis_pb2_1.AnalysisAlgorithmConfigNode]
    algorithm_configs: _containers.RepeatedCompositeFieldContainer[_algorithm_config_pb2.AlgorithmConfig]
    is_deprecated: bool
    is_deactivated: bool
    resources_locked: bool
    def __init__(self, analysis: _Optional[_Union[_analysis_pb2_1.Analysis, _Mapping]] = ..., analysis_version: _Optional[_Union[_analysis_version_pb2.AnalysisVersion, _Mapping]] = ..., id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., algorithm_config_nodes: _Optional[_Iterable[_Union[_analysis_pb2_1.AnalysisAlgorithmConfigNode, _Mapping]]] = ..., algorithm_configs: _Optional[_Iterable[_Union[_algorithm_config_pb2.AlgorithmConfig, _Mapping]]] = ..., is_deprecated: bool = ..., is_deactivated: bool = ..., resources_locked: bool = ...) -> None: ...

class AnalysisConfigCreateRequest(_message.Message):
    __slots__ = ("analysis_version_id", "name", "description", "algorithm_config_nodes")
    ANALYSIS_VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIG_NODES_FIELD_NUMBER: _ClassVar[int]
    analysis_version_id: str
    name: str
    description: str
    algorithm_config_nodes: _containers.RepeatedCompositeFieldContainer[_analysis_pb2_1.AnalysisAlgorithmConfigNode]
    def __init__(self, analysis_version_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., algorithm_config_nodes: _Optional[_Iterable[_Union[_analysis_pb2_1.AnalysisAlgorithmConfigNode, _Mapping]]] = ...) -> None: ...

class AnalysisConfigCreateResponse(_message.Message):
    __slots__ = ("status_code", "analysis_config")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_CONFIG_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analysis_config: AnalysisConfig
    def __init__(self, status_code: _Optional[int] = ..., analysis_config: _Optional[_Union[AnalysisConfig, _Mapping]] = ...) -> None: ...

class AnalysisConfigUpdateRequest(_message.Message):
    __slots__ = ("id", "name", "description", "algorithm_config_nodes")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIG_NODES_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    algorithm_config_nodes: _containers.RepeatedCompositeFieldContainer[_analysis_pb2_1.AnalysisAlgorithmConfigNode]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., algorithm_config_nodes: _Optional[_Iterable[_Union[_analysis_pb2_1.AnalysisAlgorithmConfigNode, _Mapping]]] = ...) -> None: ...

class AnalysisConfigUpdateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AnalysisConfigGetRequest(_message.Message):
    __slots__ = ("ids", "include_algorithm_details", "pagination")
    IDS_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_ALGORITHM_DETAILS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    include_algorithm_details: bool
    pagination: _common_models_pb2_1_1_1.Pagination
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., include_algorithm_details: bool = ..., pagination: _Optional[_Union[_common_models_pb2_1_1_1.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisConfigGetResponse(_message.Message):
    __slots__ = ("status_code", "analysis_configs", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analysis_configs: _containers.RepeatedCompositeFieldContainer[AnalysisConfig]
    pagination: _common_models_pb2_1_1_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., analysis_configs: _Optional[_Iterable[_Union[AnalysisConfig, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1_1_1.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisConfigListRequest(_message.Message):
    __slots__ = ("analysis_id", "analysis_version_id", "search_text", "min_created_on", "max_created_on", "include_deactivated", "subject_id", "pagination")
    ANALYSIS_ID_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    MIN_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    MAX_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_DEACTIVATED_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    analysis_id: str
    analysis_version_id: str
    search_text: str
    min_created_on: _timestamp_pb2.Timestamp
    max_created_on: _timestamp_pb2.Timestamp
    include_deactivated: bool
    subject_id: str
    pagination: _common_models_pb2_1_1_1.Pagination
    def __init__(self, analysis_id: _Optional[str] = ..., analysis_version_id: _Optional[str] = ..., search_text: _Optional[str] = ..., min_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., include_deactivated: bool = ..., subject_id: _Optional[str] = ..., pagination: _Optional[_Union[_common_models_pb2_1_1_1.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisConfigListResponse(_message.Message):
    __slots__ = ("status_code", "analysis_configs", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analysis_configs: _containers.RepeatedCompositeFieldContainer[AnalysisConfig]
    pagination: _common_models_pb2_1_1_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., analysis_configs: _Optional[_Iterable[_Union[AnalysisConfig, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1_1_1.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisConfigDeactivateRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AnalysisConfigDeactivateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



from . import algorithm_computation_execution_pb2 as algorithm_computation_execution
from . import algorithm_computation_pb2 as algorithm_computation
from . import algorithm_config_pb2 as algorithm_config
from . import algorithm_manifest_pb2 as algorithm_manifest
from . import algorithm_pb2 as algorithm
from . import algorithm_version_pb2 as algorithm_version
from . import analysis_computation_pb2 as analysis_computation
from . import analysis_config_pb2 as analysis_config
from . import analysis_pb2 as analysis
from . import analysis_version_pb2 as analysis_version
from . import aoi_catalog_pb2 as aoi_catalog
from . import aoi_collection_pb2 as aoi_collection
from . import aoi_export_pb2 as aoi_export
from . import aoi_pb2 as aoi
from . import aoi_transaction_pb2 as aoi_transaction
from . import aoi_version_pb2 as aoi_version
from . import common_models_pb2 as common_models
from . import credit_pb2 as credit
from . import data_search_pb2 as data_search
from . import data_source_pb2 as data_source
from . import data_type_pb2 as data_type
from . import forgot_password_pb2 as forgot_password
from . import imagery_pb2 as imagery
from . import notification_pb2 as notification
from . import permission_pb2 as permission
from . import project_analysis_config_pb2 as project_analysis_config
from . import project_aoi_pb2 as project_aoi
from . import project_collaborator_pb2 as project_collaborator
from . import project_group_pb2 as project_group
from . import project_pb2 as project
from . import project_result_pb2 as project_result
from . import resource_pb2 as resource
from . import result_pb2 as result
from . import subject_pb2 as subject
from . import system_pb2 as system
from . import tile_pb2 as tile
from . import toi_pb2 as toi
from . import token_pb2 as token
from . import user_collection_pb2 as user_collection
from . import user_pb2 as user
from . import visualization_pb2 as visualization



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import aoi_version_pb2 as aoi__version__pb2

GRPC_GENERATED_VERSION = '1.66.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in aoi_version_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AOIVersionApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.AOIVersionApi/create',
                request_serializer=aoi__version__pb2.AOIVersionCreateRequest.SerializeToString,
                response_deserializer=aoi__version__pb2.AOIVersionCreateResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.AOIVersionApi/get',
                request_serializer=aoi__version__pb2.AOIVersionGetRequest.SerializeToString,
                response_deserializer=aoi__version__pb2.AOIVersionGetResponse.FromString,
                _registered_method=True)
        self.list = channel.unary_unary(
                '/oi.papi.AOIVersionApi/list',
                request_serializer=aoi__version__pb2.AOIVersionListRequest.SerializeToString,
                response_deserializer=aoi__version__pb2.AOIVersionListResponse.FromString,
                _registered_method=True)


class AOIVersionApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Create a new AOIVersion that is tied to the original AOI by reference of the aoi_id.
        After specifying the aoi modifications, the original is copied and modified. Further, AOIVersions are immutable.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get the actual AOI details specified by the provided version. Additionally, choose which metadata fields should be returned.
        A list of AOICollections that the AOIVersion is a part of is also returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        List the available AOIVersions, including on the latest versions by default that match the specific filters.
        Additional options include the ability to list out all fields of the AOIVersion by setting the verbose flag to True.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AOIVersionApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=aoi__version__pb2.AOIVersionCreateRequest.FromString,
                    response_serializer=aoi__version__pb2.AOIVersionCreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=aoi__version__pb2.AOIVersionGetRequest.FromString,
                    response_serializer=aoi__version__pb2.AOIVersionGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=aoi__version__pb2.AOIVersionListRequest.FromString,
                    response_serializer=aoi__version__pb2.AOIVersionListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AOIVersionApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.AOIVersionApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AOIVersionApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOIVersionApi/create',
            aoi__version__pb2.AOIVersionCreateRequest.SerializeToString,
            aoi__version__pb2.AOIVersionCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOIVersionApi/get',
            aoi__version__pb2.AOIVersionGetRequest.SerializeToString,
            aoi__version__pb2.AOIVersionGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOIVersionApi/list',
            aoi__version__pb2.AOIVersionListRequest.SerializeToString,
            aoi__version__pb2.AOIVersionListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class AlgorithmComputation(_message.Message):
    __slots__ = ("id", "aoi_collection_id", "algo_config_id", "toi_id", "input_ids", "submitted_on", "state", "progress", "last_execution")
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATE: _ClassVar[AlgorithmComputation.State]
        NOT_STARTED: _ClassVar[AlgorithmComputation.State]
        IN_PROGRESS: _ClassVar[AlgorithmComputation.State]
        PAUSED: _ClassVar[AlgorithmComputation.State]
        COMPLETE: _ClassVar[AlgorithmComputation.State]
    UNKNOWN_STATE: AlgorithmComputation.State
    NOT_STARTED: AlgorithmComputation.State
    IN_PROGRESS: AlgorithmComputation.State
    PAUSED: AlgorithmComputation.State
    COMPLETE: AlgorithmComputation.State
    class Progress(_message.Message):
        __slots__ = ("running", "succeeded", "failed", "no_data")
        RUNNING_FIELD_NUMBER: _ClassVar[int]
        SUCCEEDED_FIELD_NUMBER: _ClassVar[int]
        FAILED_FIELD_NUMBER: _ClassVar[int]
        NO_DATA_FIELD_NUMBER: _ClassVar[int]
        running: float
        succeeded: float
        failed: float
        no_data: float
        def __init__(self, running: _Optional[float] = ..., succeeded: _Optional[float] = ..., failed: _Optional[float] = ..., no_data: _Optional[float] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    ALGO_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    TOI_ID_FIELD_NUMBER: _ClassVar[int]
    INPUT_IDS_FIELD_NUMBER: _ClassVar[int]
    SUBMITTED_ON_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    LAST_EXECUTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    aoi_collection_id: str
    algo_config_id: str
    toi_id: str
    input_ids: _containers.RepeatedScalarFieldContainer[str]
    submitted_on: _timestamp_pb2.Timestamp
    state: AlgorithmComputation.State
    progress: AlgorithmComputation.Progress
    last_execution: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., aoi_collection_id: _Optional[str] = ..., algo_config_id: _Optional[str] = ..., toi_id: _Optional[str] = ..., input_ids: _Optional[_Iterable[str]] = ..., submitted_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., state: _Optional[_Union[AlgorithmComputation.State, str]] = ..., progress: _Optional[_Union[AlgorithmComputation.Progress, _Mapping]] = ..., last_execution: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AlgorithmComputationCreateRequest(_message.Message):
    __slots__ = ("algorithm_config_id", "aoi_collection_id", "toi_id")
    ALGORITHM_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    TOI_ID_FIELD_NUMBER: _ClassVar[int]
    algorithm_config_id: str
    aoi_collection_id: str
    toi_id: str
    def __init__(self, algorithm_config_id: _Optional[str] = ..., aoi_collection_id: _Optional[str] = ..., toi_id: _Optional[str] = ...) -> None: ...

class AlgorithmComputationCreateResponse(_message.Message):
    __slots__ = ("status_code", "algorithm_computation")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_COMPUTATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    algorithm_computation: AlgorithmComputation
    def __init__(self, status_code: _Optional[int] = ..., algorithm_computation: _Optional[_Union[AlgorithmComputation, _Mapping]] = ...) -> None: ...

class AlgorithmComputationRunRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AlgorithmComputationRunResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AlgorithmComputationGetRequest(_message.Message):
    __slots__ = ("ids", "pagination")
    IDS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    pagination: _common_models_pb2.Pagination
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class AlgorithmComputationGetResponse(_message.Message):
    __slots__ = ("status_code", "algorithm_computations", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_COMPUTATIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    algorithm_computations: _containers.RepeatedCompositeFieldContainer[AlgorithmComputation]
    pagination: _common_models_pb2.Pagination
    def __init__(self, status_code: _Optional[int] = ..., algorithm_computations: _Optional[_Iterable[_Union[AlgorithmComputation, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class AlgorithmComputationListRequest(_message.Message):
    __slots__ = ("state", "min_submitted_on", "max_submitted_on", "algorithm_config_id", "toi_id", "aoi_collection_id", "pagination")
    STATE_FIELD_NUMBER: _ClassVar[int]
    MIN_SUBMITTED_ON_FIELD_NUMBER: _ClassVar[int]
    MAX_SUBMITTED_ON_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    TOI_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    state: AlgorithmComputation.State
    min_submitted_on: _timestamp_pb2.Timestamp
    max_submitted_on: _timestamp_pb2.Timestamp
    algorithm_config_id: str
    toi_id: str
    aoi_collection_id: str
    pagination: _common_models_pb2.Pagination
    def __init__(self, state: _Optional[_Union[AlgorithmComputation.State, str]] = ..., min_submitted_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_submitted_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., algorithm_config_id: _Optional[str] = ..., toi_id: _Optional[str] = ..., aoi_collection_id: _Optional[str] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class AlgorithmComputationListResponse(_message.Message):
    __slots__ = ("status_code", "algorithm_computations", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_COMPUTATIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    algorithm_computations: _containers.RepeatedCompositeFieldContainer[AlgorithmComputation]
    pagination: _common_models_pb2.Pagination
    def __init__(self, status_code: _Optional[int] = ..., algorithm_computations: _Optional[_Iterable[_Union[AlgorithmComputation, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...



import common_models_pb2 as _common_models_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class UserForgotPasswordRequest(_message.Message):
    __slots__ = ("user_email",)
    USER_EMAIL_FIELD_NUMBER: _ClassVar[int]
    user_email: str
    def __init__(self, user_email: _Optional[str] = ...) -> None: ...

class UserForgotPasswordResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
import algorithm_pb2 as _algorithm_pb2
import common_models_pb2 as _common_models_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from algorithm_pb2 import Algorithm as Algorithm
from algorithm_pb2 import AlgorithmCreateRequest as AlgorithmCreateRequest
from algorithm_pb2 import AlgorithmCreateResponse as AlgorithmCreateResponse
from algorithm_pb2 import AlgorithmGetRequest as AlgorithmGetRequest
from algorithm_pb2 import AlgorithmGetResponse as AlgorithmGetResponse
from algorithm_pb2 import AlgorithmListRequest as AlgorithmListRequest
from algorithm_pb2 import AlgorithmListResponse as AlgorithmListResponse
from algorithm_pb2 import AlgorithmUpdateRequest as AlgorithmUpdateRequest
from algorithm_pb2 import AlgorithmUpdateResponse as AlgorithmUpdateResponse

DESCRIPTOR: _descriptor.FileDescriptor

class Manifest(_message.Message):
    __slots__ = ("metadata", "inputs", "outputs", "container_parameters", "interface", "resource_request", "parameters", "manifest_version")
    class Metadata(_message.Message):
        __slots__ = ("description", "version", "tags")
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        TAGS_FIELD_NUMBER: _ClassVar[int]
        description: str
        version: str
        tags: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, description: _Optional[str] = ..., version: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...
    class Interface(_message.Message):
        __slots__ = ("interface_type", "adapter")
        INTERFACE_TYPE_FIELD_NUMBER: _ClassVar[int]
        ADAPTER_FIELD_NUMBER: _ClassVar[int]
        interface_type: str
        adapter: str
        def __init__(self, interface_type: _Optional[str] = ..., adapter: _Optional[str] = ...) -> None: ...
    class AlgorithmInputs(_message.Message):
        __slots__ = ("data_type_name", "min_count", "max_count")
        DATA_TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        MIN_COUNT_FIELD_NUMBER: _ClassVar[int]
        MAX_COUNT_FIELD_NUMBER: _ClassVar[int]
        data_type_name: str
        min_count: int
        max_count: int
        def __init__(self, data_type_name: _Optional[str] = ..., min_count: _Optional[int] = ..., max_count: _Optional[int] = ...) -> None: ...
    class AlgorithmOutputs(_message.Message):
        __slots__ = ("observation_value_columns", "data_type_name")
        OBSERVATION_VALUE_COLUMNS_FIELD_NUMBER: _ClassVar[int]
        DATA_TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
        observation_value_columns: _containers.RepeatedScalarFieldContainer[str]
        data_type_name: str
        def __init__(self, observation_value_columns: _Optional[_Iterable[str]] = ..., data_type_name: _Optional[str] = ...) -> None: ...
    class ContainerParameters(_message.Message):
        __slots__ = ("image", "resource_request", "command")
        IMAGE_FIELD_NUMBER: _ClassVar[int]
        RESOURCE_REQUEST_FIELD_NUMBER: _ClassVar[int]
        COMMAND_FIELD_NUMBER: _ClassVar[int]
        image: str
        resource_request: Manifest.ResourceRequest
        command: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, image: _Optional[str] = ..., resource_request: _Optional[_Union[Manifest.ResourceRequest, _Mapping]] = ..., command: _Optional[_Iterable[str]] = ...) -> None: ...
    class ResourceRequest(_message.Message):
        __slots__ = ("gpu", "memory_gb", "cpu_millicore")
        GPU_FIELD_NUMBER: _ClassVar[int]
        MEMORY_GB_FIELD_NUMBER: _ClassVar[int]
        CPU_MILLICORE_FIELD_NUMBER: _ClassVar[int]
        gpu: int
        memory_gb: int
        cpu_millicore: int
        def __init__(self, gpu: _Optional[int] = ..., memory_gb: _Optional[int] = ..., cpu_millicore: _Optional[int] = ...) -> None: ...
    class Parameter(_message.Message):
        __slots__ = ("name", "type", "units", "description", "min", "max", "allowed_values", "default")
        NAME_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        UNITS_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        MIN_FIELD_NUMBER: _ClassVar[int]
        MAX_FIELD_NUMBER: _ClassVar[int]
        ALLOWED_VALUES_FIELD_NUMBER: _ClassVar[int]
        DEFAULT_FIELD_NUMBER: _ClassVar[int]
        name: str
        type: int
        units: str
        description: str
        min: int
        max: int
        allowed_values: _containers.RepeatedScalarFieldContainer[str]
        default: int
        def __init__(self, name: _Optional[str] = ..., type: _Optional[int] = ..., units: _Optional[str] = ..., description: _Optional[str] = ..., min: _Optional[int] = ..., max: _Optional[int] = ..., allowed_values: _Optional[_Iterable[str]] = ..., default: _Optional[int] = ...) -> None: ...
    METADATA_FIELD_NUMBER: _ClassVar[int]
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    CONTAINER_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    MANIFEST_VERSION_FIELD_NUMBER: _ClassVar[int]
    metadata: Manifest.Metadata
    inputs: _containers.RepeatedCompositeFieldContainer[Manifest.AlgorithmInputs]
    outputs: _containers.RepeatedCompositeFieldContainer[Manifest.AlgorithmOutputs]
    container_parameters: Manifest.ContainerParameters
    interface: Manifest.Interface
    resource_request: Manifest.ResourceRequest
    parameters: _containers.RepeatedCompositeFieldContainer[Manifest.Parameter]
    manifest_version: str
    def __init__(self, metadata: _Optional[_Union[Manifest.Metadata, _Mapping]] = ..., inputs: _Optional[_Iterable[_Union[Manifest.AlgorithmInputs, _Mapping]]] = ..., outputs: _Optional[_Iterable[_Union[Manifest.AlgorithmOutputs, _Mapping]]] = ..., container_parameters: _Optional[_Union[Manifest.ContainerParameters, _Mapping]] = ..., interface: _Optional[_Union[Manifest.Interface, _Mapping]] = ..., resource_request: _Optional[_Union[Manifest.ResourceRequest, _Mapping]] = ..., parameters: _Optional[_Iterable[_Union[Manifest.Parameter, _Mapping]]] = ..., manifest_version: _Optional[str] = ...) -> None: ...

class AlgorithmVersion(_message.Message):
    __slots__ = ("id", "algorithm", "version", "manifest", "created_on", "is_deactivated", "is_deprecated")
    ID_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    MANIFEST_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    IS_DEACTIVATED_FIELD_NUMBER: _ClassVar[int]
    IS_DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    id: str
    algorithm: _algorithm_pb2.Algorithm
    version: str
    manifest: _struct_pb2.Struct
    created_on: _timestamp_pb2.Timestamp
    is_deactivated: bool
    is_deprecated: bool
    def __init__(self, id: _Optional[str] = ..., algorithm: _Optional[_Union[_algorithm_pb2.Algorithm, _Mapping]] = ..., version: _Optional[str] = ..., manifest: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., is_deactivated: bool = ..., is_deprecated: bool = ...) -> None: ...

class AlgorithmVersionCreateRequest(_message.Message):
    __slots__ = ("algorithm_id", "manifest_struct", "manifest_message")
    ALGORITHM_ID_FIELD_NUMBER: _ClassVar[int]
    MANIFEST_STRUCT_FIELD_NUMBER: _ClassVar[int]
    MANIFEST_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    algorithm_id: str
    manifest_struct: _struct_pb2.Struct
    manifest_message: Manifest
    def __init__(self, algorithm_id: _Optional[str] = ..., manifest_struct: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., manifest_message: _Optional[_Union[Manifest, _Mapping]] = ...) -> None: ...

class AlgorithmVersionCreateResponse(_message.Message):
    __slots__ = ("status_code", "algorithm_version")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_VERSION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    algorithm_version: AlgorithmVersion
    def __init__(self, status_code: _Optional[int] = ..., algorithm_version: _Optional[_Union[AlgorithmVersion, _Mapping]] = ...) -> None: ...

class AlgorithmVersionGetRequest(_message.Message):
    __slots__ = ("ids", "pagination")
    IDS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class AlgorithmVersionGetResponse(_message.Message):
    __slots__ = ("status_code", "algorithm_versions", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    algorithm_versions: _containers.RepeatedCompositeFieldContainer[AlgorithmVersion]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., algorithm_versions: _Optional[_Iterable[_Union[AlgorithmVersion, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class AlgorithmVersionListRequest(_message.Message):
    __slots__ = ("algorithm_id", "search_text", "tag", "min_created_on", "max_created_on", "include_all_versions", "pagination")
    ALGORITHM_ID_FIELD_NUMBER: _ClassVar[int]
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    TAG_FIELD_NUMBER: _ClassVar[int]
    MIN_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    MAX_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_ALL_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    algorithm_id: str
    search_text: str
    tag: str
    min_created_on: _timestamp_pb2.Timestamp
    max_created_on: _timestamp_pb2.Timestamp
    include_all_versions: bool
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, algorithm_id: _Optional[str] = ..., search_text: _Optional[str] = ..., tag: _Optional[str] = ..., min_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., include_all_versions: bool = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class AlgorithmVersionListResponse(_message.Message):
    __slots__ = ("status_code", "algorithm_versions", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    algorithm_versions: _containers.RepeatedCompositeFieldContainer[AlgorithmVersion]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., algorithm_versions: _Optional[_Iterable[_Union[AlgorithmVersion, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class AlgorithmVersionDeprecateRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AlgorithmVersionDeprecateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AlgorithmVersionDeactivateRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AlgorithmVersionDeactivateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AlgorithmVersionActivateRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AlgorithmVersionActivateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import algorithm_config_pb2 as algorithm__config__pb2

GRPC_GENERATED_VERSION = '1.66.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in algorithm_config_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AlgorithmConfigApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.AlgorithmConfigApi/create',
                request_serializer=algorithm__config__pb2.AlgorithmConfigCreateRequest.SerializeToString,
                response_deserializer=algorithm__config__pb2.AlgorithmConfigCreateResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.AlgorithmConfigApi/get',
                request_serializer=algorithm__config__pb2.AlgorithmConfigGetRequest.SerializeToString,
                response_deserializer=algorithm__config__pb2.AlgorithmConfigGetResponse.FromString,
                _registered_method=True)
        self.list = channel.unary_unary(
                '/oi.papi.AlgorithmConfigApi/list',
                request_serializer=algorithm__config__pb2.AlgorithmConfigListRequest.SerializeToString,
                response_deserializer=algorithm__config__pb2.AlgorithmConfigListResponse.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/oi.papi.AlgorithmConfigApi/update',
                request_serializer=algorithm__config__pb2.AlgorithmConfigUpdateRequest.SerializeToString,
                response_deserializer=algorithm__config__pb2.AlgorithmConfigUpdateResponse.FromString,
                _registered_method=True)
        self.deprecate = channel.unary_unary(
                '/oi.papi.AlgorithmConfigApi/deprecate',
                request_serializer=algorithm__config__pb2.AlgorithmConfigDeprecateRequest.SerializeToString,
                response_deserializer=algorithm__config__pb2.AlgorithmConfigDeprecateResponse.FromString,
                _registered_method=True)
        self.deactivate = channel.unary_unary(
                '/oi.papi.AlgorithmConfigApi/deactivate',
                request_serializer=algorithm__config__pb2.AlgorithmConfigDeactivateRequest.SerializeToString,
                response_deserializer=algorithm__config__pb2.AlgorithmConfigDeactivateResponse.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/oi.papi.AlgorithmConfigApi/delete',
                request_serializer=algorithm__config__pb2.AlgorithmConfigDeleteRequest.SerializeToString,
                response_deserializer=algorithm__config__pb2.AlgorithmConfigDeleteResponse.FromString,
                _registered_method=True)


class AlgorithmConfigApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Creates a configuration of the specified AlgorithmVersion, including concrete values for all of the algorithm parameters.
        This configuration is stored in the system and the AlgorithmConfig is returned to the user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Retrieve the metadata of a particular AlgorithmConfig.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        Retrieve the metadata for all AlgorithmConfigs that this user has access to and that match the provided search filters.
        By default, deactivated AlgorithmConfig are not returned. Setting include_deactivated to true will also return any AlgorithmConfig that have been deactivated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        Update details of an AlgorithmConfig, so long as it has not been locked.
        Once the AlgorithmConfig is used in an AlgorithmComputation, it is permanently locked and the specific parameter values can no longer be updated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deprecate(self, request, context):
        """
        Deprecate the specific configuration of an AlgorithmConfig.
        Deprecated AlgorithmConfig can still be searched for, metadata can be retrieved, and can still be used in new AlgorithmComputations, but they are no longer actively supported.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deactivate(self, request, context):
        """
        Deactivate the specific configuration of an AlgorithmConfig.
        Deactivated AlgorithmConfig will no longer show up in searches, but metadata can still be retrieved for deactivated AlgorithmConfigs via the get endpoint.
        Deactivated AlgorithmConfig cannot be used in any new AlgorithmComputations, but existing AlgorithmComputations will continue to function properly.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        Delete the specified AlgorithmConfig, if and only if it has not been used to create an AlgorithmComputation.
        Once an AlgorithmConfig has been used to create an AlgorithmComputation it can never be deleted.
        The user must have permission to access the specified Algorithm.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlgorithmConfigApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=algorithm__config__pb2.AlgorithmConfigCreateRequest.FromString,
                    response_serializer=algorithm__config__pb2.AlgorithmConfigCreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=algorithm__config__pb2.AlgorithmConfigGetRequest.FromString,
                    response_serializer=algorithm__config__pb2.AlgorithmConfigGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=algorithm__config__pb2.AlgorithmConfigListRequest.FromString,
                    response_serializer=algorithm__config__pb2.AlgorithmConfigListResponse.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=algorithm__config__pb2.AlgorithmConfigUpdateRequest.FromString,
                    response_serializer=algorithm__config__pb2.AlgorithmConfigUpdateResponse.SerializeToString,
            ),
            'deprecate': grpc.unary_unary_rpc_method_handler(
                    servicer.deprecate,
                    request_deserializer=algorithm__config__pb2.AlgorithmConfigDeprecateRequest.FromString,
                    response_serializer=algorithm__config__pb2.AlgorithmConfigDeprecateResponse.SerializeToString,
            ),
            'deactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.deactivate,
                    request_deserializer=algorithm__config__pb2.AlgorithmConfigDeactivateRequest.FromString,
                    response_serializer=algorithm__config__pb2.AlgorithmConfigDeactivateResponse.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=algorithm__config__pb2.AlgorithmConfigDeleteRequest.FromString,
                    response_serializer=algorithm__config__pb2.AlgorithmConfigDeleteResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AlgorithmConfigApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.AlgorithmConfigApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AlgorithmConfigApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmConfigApi/create',
            algorithm__config__pb2.AlgorithmConfigCreateRequest.SerializeToString,
            algorithm__config__pb2.AlgorithmConfigCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmConfigApi/get',
            algorithm__config__pb2.AlgorithmConfigGetRequest.SerializeToString,
            algorithm__config__pb2.AlgorithmConfigGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmConfigApi/list',
            algorithm__config__pb2.AlgorithmConfigListRequest.SerializeToString,
            algorithm__config__pb2.AlgorithmConfigListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmConfigApi/update',
            algorithm__config__pb2.AlgorithmConfigUpdateRequest.SerializeToString,
            algorithm__config__pb2.AlgorithmConfigUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def deprecate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmConfigApi/deprecate',
            algorithm__config__pb2.AlgorithmConfigDeprecateRequest.SerializeToString,
            algorithm__config__pb2.AlgorithmConfigDeprecateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def deactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmConfigApi/deactivate',
            algorithm__config__pb2.AlgorithmConfigDeactivateRequest.SerializeToString,
            algorithm__config__pb2.AlgorithmConfigDeactivateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmConfigApi/delete',
            algorithm__config__pb2.AlgorithmConfigDeleteRequest.SerializeToString,
            algorithm__config__pb2.AlgorithmConfigDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class CreditAddRequest(_message.Message):
    __slots__ = ("source_id", "amount", "reason")
    SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    source_id: str
    amount: float
    reason: str
    def __init__(self, source_id: _Optional[str] = ..., amount: _Optional[float] = ..., reason: _Optional[str] = ...) -> None: ...

class CreditAddResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class CreditRemoveRequest(_message.Message):
    __slots__ = ("source_id", "amount", "reason")
    SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    source_id: str
    amount: float
    reason: str
    def __init__(self, source_id: _Optional[str] = ..., amount: _Optional[float] = ..., reason: _Optional[str] = ...) -> None: ...

class CreditRemoveResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class CreditRefundRequest(_message.Message):
    __slots__ = ("source_id", "amount", "reason")
    SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    source_id: str
    amount: float
    reason: str
    def __init__(self, source_id: _Optional[str] = ..., amount: _Optional[float] = ..., reason: _Optional[str] = ...) -> None: ...

class CreditRefundResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class CreditAlgorithmMultiplierSetRequest(_message.Message):
    __slots__ = ("algorithm_version_id", "algorithm_execution_price", "algorithm_value_price")
    ALGORITHM_VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_EXECUTION_PRICE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_VALUE_PRICE_FIELD_NUMBER: _ClassVar[int]
    algorithm_version_id: str
    algorithm_execution_price: float
    algorithm_value_price: float
    def __init__(self, algorithm_version_id: _Optional[str] = ..., algorithm_execution_price: _Optional[float] = ..., algorithm_value_price: _Optional[float] = ...) -> None: ...

class CreditAlgorithmMultiplierSetResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class CreditDataSourceMultiplierSetRequest(_message.Message):
    __slots__ = ("data_source_id", "data_source_price")
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCE_PRICE_FIELD_NUMBER: _ClassVar[int]
    data_source_id: str
    data_source_price: float
    def __init__(self, data_source_id: _Optional[str] = ..., data_source_price: _Optional[float] = ...) -> None: ...

class CreditDataSourceMultiplierSetResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class CreditEstimateRequest(_message.Message):
    __slots__ = ("algorithm_computation_id", "analysis_computation_ids", "analysis_resources")
    class AnalysisResources(_message.Message):
        __slots__ = ("aoi_collection_ids", "analysis_config_ids", "start_ts", "end_ts")
        AOI_COLLECTION_IDS_FIELD_NUMBER: _ClassVar[int]
        ANALYSIS_CONFIG_IDS_FIELD_NUMBER: _ClassVar[int]
        START_TS_FIELD_NUMBER: _ClassVar[int]
        END_TS_FIELD_NUMBER: _ClassVar[int]
        aoi_collection_ids: _containers.RepeatedScalarFieldContainer[str]
        analysis_config_ids: _containers.RepeatedScalarFieldContainer[str]
        start_ts: _timestamp_pb2.Timestamp
        end_ts: _timestamp_pb2.Timestamp
        def __init__(self, aoi_collection_ids: _Optional[_Iterable[str]] = ..., analysis_config_ids: _Optional[_Iterable[str]] = ..., start_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    ALGORITHM_COMPUTATION_ID_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_COMPUTATION_IDS_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_RESOURCES_FIELD_NUMBER: _ClassVar[int]
    algorithm_computation_id: str
    analysis_computation_ids: _containers.RepeatedScalarFieldContainer[str]
    analysis_resources: CreditEstimateRequest.AnalysisResources
    def __init__(self, algorithm_computation_id: _Optional[str] = ..., analysis_computation_ids: _Optional[_Iterable[str]] = ..., analysis_resources: _Optional[_Union[CreditEstimateRequest.AnalysisResources, _Mapping]] = ...) -> None: ...

class CreditEstimateResponse(_message.Message):
    __slots__ = ("status_code", "credit_estimate", "msg")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    CREDIT_ESTIMATE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    credit_estimate: float
    msg: str
    def __init__(self, status_code: _Optional[int] = ..., credit_estimate: _Optional[float] = ..., msg: _Optional[str] = ...) -> None: ...

class Credit(_message.Message):
    __slots__ = ("source_id", "available", "reserved", "used")
    SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    RESERVED_FIELD_NUMBER: _ClassVar[int]
    USED_FIELD_NUMBER: _ClassVar[int]
    source_id: str
    available: float
    reserved: float
    used: float
    def __init__(self, source_id: _Optional[str] = ..., available: _Optional[float] = ..., reserved: _Optional[float] = ..., used: _Optional[float] = ...) -> None: ...

class CreditSummaryRequest(_message.Message):
    __slots__ = ("source_id",)
    SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    source_id: str
    def __init__(self, source_id: _Optional[str] = ...) -> None: ...

class CreditSummaryResponse(_message.Message):
    __slots__ = ("status_code", "credit")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    CREDIT_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    credit: Credit
    def __init__(self, status_code: _Optional[int] = ..., credit: _Optional[_Union[Credit, _Mapping]] = ...) -> None: ...

class Transaction(_message.Message):
    __slots__ = ("id", "credit_source_id", "user_id", "transaction_type", "amount", "reason", "transacted_on", "credit_available", "credit_reserved", "credit_used", "algorithm_computation_id")
    class TransactionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_TRANSACTION_TYPE: _ClassVar[Transaction.TransactionType]
        ADD: _ClassVar[Transaction.TransactionType]
        REMOVE: _ClassVar[Transaction.TransactionType]
        REFUND: _ClassVar[Transaction.TransactionType]
        RESERVE: _ClassVar[Transaction.TransactionType]
        UNRESERVE: _ClassVar[Transaction.TransactionType]
        DEDUCT: _ClassVar[Transaction.TransactionType]
    UNKNOWN_TRANSACTION_TYPE: Transaction.TransactionType
    ADD: Transaction.TransactionType
    REMOVE: Transaction.TransactionType
    REFUND: Transaction.TransactionType
    RESERVE: Transaction.TransactionType
    UNRESERVE: Transaction.TransactionType
    DEDUCT: Transaction.TransactionType
    ID_FIELD_NUMBER: _ClassVar[int]
    CREDIT_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    TRANSACTED_ON_FIELD_NUMBER: _ClassVar[int]
    CREDIT_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    CREDIT_RESERVED_FIELD_NUMBER: _ClassVar[int]
    CREDIT_USED_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_COMPUTATION_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    credit_source_id: str
    user_id: str
    transaction_type: Transaction.TransactionType
    amount: float
    reason: str
    transacted_on: _timestamp_pb2.Timestamp
    credit_available: float
    credit_reserved: float
    credit_used: float
    algorithm_computation_id: str
    def __init__(self, id: _Optional[str] = ..., credit_source_id: _Optional[str] = ..., user_id: _Optional[str] = ..., transaction_type: _Optional[_Union[Transaction.TransactionType, str]] = ..., amount: _Optional[float] = ..., reason: _Optional[str] = ..., transacted_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., credit_available: _Optional[float] = ..., credit_reserved: _Optional[float] = ..., credit_used: _Optional[float] = ..., algorithm_computation_id: _Optional[str] = ...) -> None: ...

class CreditTransactionsRequest(_message.Message):
    __slots__ = ("pagination", "source_id", "transaction_type", "min_transacted_on", "max_transacted_on", "algorithm_computation_id")
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    MIN_TRANSACTED_ON_FIELD_NUMBER: _ClassVar[int]
    MAX_TRANSACTED_ON_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_COMPUTATION_ID_FIELD_NUMBER: _ClassVar[int]
    pagination: _common_models_pb2.Pagination
    source_id: str
    transaction_type: Transaction.TransactionType
    min_transacted_on: _timestamp_pb2.Timestamp
    max_transacted_on: _timestamp_pb2.Timestamp
    algorithm_computation_id: str
    def __init__(self, pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ..., source_id: _Optional[str] = ..., transaction_type: _Optional[_Union[Transaction.TransactionType, str]] = ..., min_transacted_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_transacted_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., algorithm_computation_id: _Optional[str] = ...) -> None: ...

class CreditTransactionsResponse(_message.Message):
    __slots__ = ("status_code", "pagination", "transactions")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    pagination: _common_models_pb2.Pagination
    transactions: _containers.RepeatedCompositeFieldContainer[Transaction]
    def __init__(self, status_code: _Optional[int] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ..., transactions: _Optional[_Iterable[_Union[Transaction, _Mapping]]] = ...) -> None: ...
